==> igniteui-webcomponents-spreadsheet-4.6.0.tgz: package/esm5/lib/FormatCellsDialogData.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, toNullable, Boolean_$type, Number_$type, markType } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
var FormatCellsDialogData = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FormatCellsDialogData, _super);
    function FormatCellsDialogData() {
        var _this = _super.call(this) || this;
        _this.p = null;
        _this.b = 0;
        _this.q = null;
        _this.j = 0;
        _this.c = 0;
        _this.i = null;
        _this.z = toNullable(Boolean_$type, null);
        _this.r = null;
        _this.x = 0;
        _this.aa = toNullable(Boolean_$type, null);
        _this.ah = null;
        _this.ab = toNullable(Boolean_$type, null);
        _this.k = 0;
        _this.l = 0;
        _this.ai = null;
        _this.m = 0;
        _this.y = 0;
        _this.s = null;
        _this.d = 0;
        _this.t = null;
        _this.e = 0;
        _this.u = null;
        _this.f = 0;
        _this.ac = toNullable(Boolean_$type, null);
        _this.ad = toNullable(Boolean_$type, null);
        _this.v = null;
        _this.g = 0;
        _this.ae = toNullable(Number_$type, null);
        _this.af = toNullable(Boolean_$type, null);
        _this.w = null;
        _this.h = 0;
        _this.n = 0;
        _this.o = null;
        _this.ag = toNullable(Boolean_$type, null);
        return _this;
    }
    FormatCellsDialogData.prototype.a = function () {
        return this.memberwiseClone();
    };
    FormatCellsDialogData.$t = markType(FormatCellsDialogData, 'FormatCellsDialogData');
    return FormatCellsDialogData;
}(Base));
export { FormatCellsDialogData };

==> igniteui-webcomponents-spreadsheet-4.8.1.tgz: package/esm5/lib/FormatCellsDialogData.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, toNullable, Boolean_$type, Number_$type, markType } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
var FormatCellsDialogData = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FormatCellsDialogData, _super);
    function FormatCellsDialogData() {
        var _this = _super.call(this) || this;
        _this.p = null;
        _this.b = 0;
        _this.q = null;
        _this.j = 0;
        _this.c = 0;
        _this.i = null;
        _this.z = toNullable(Boolean_$type, null);
        _this.r = null;
        _this.x = 0;
        _this.aa = toNullable(Boolean_$type, null);
        _this.ai = null;
        _this.ab = toNullable(Boolean_$type, null);
        _this.k = 0;
        _this.l = 0;
        _this.aj = null;
        _this.m = 0;
        _this.y = 0;
        _this.s = null;
        _this.d = 0;
        _this.t = null;
        _this.e = 0;
        _this.u = null;
        _this.f = 0;
        _this.ac = toNullable(Boolean_$type, null);
        _this.ad = toNullable(Boolean_$type, null);
        _this.ae = toNullable(Boolean_$type, null);
        _this.v = null;
        _this.g = 0;
        _this.af = toNullable(Number_$type, null);
        _this.ag = toNullable(Boolean_$type, null);
        _this.w = null;
        _this.h = 0;
        _this.n = 0;
        _this.o = null;
        _this.ah = toNullable(Boolean_$type, null);
        return _this;
    }
    FormatCellsDialogData.prototype.a = function () {
        return this.memberwiseClone();
    };
    FormatCellsDialogData.$t = markType(FormatCellsDialogData, 'FormatCellsDialogData');
    return FormatCellsDialogData;
}(Base));
export { FormatCellsDialogData };
